@@ -1,4 +1,4 @@
-# $Id: Simple.pm,v 1.14 2003/05/20 08:46:12 grantm Exp $
+# $Id: Simple.pm,v 1.15 2003/06/13 10:27:20 grantm Exp $
 
 package XML::Simple;
 
@@ -53,7 +53,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $PREFERRED_PARSER);
 @ISA               = qw(Exporter);
 @EXPORT            = qw(XMLin XMLout);
 @EXPORT_OK         = qw(xml_in xml_out);
-$VERSION           = '2.07';
+$VERSION           = '2.08';
 $PREFERRED_PARSER  = undef;
 
 my $StrictMode     = 0;
@@ -878,6 +878,16 @@ sub collapse {
   }
 
 
+  # Do variable substitutions
+
+  if(my $var = $self->{_var_values}) {
+    while(my($key, $val) = each(%$attr)) {
+      $val =~ s{\$\{(\w+)\}}{ $self->get_var($1) }ge;
+      $attr->{$key} = $val;
+    }
+  }
+
+
   # Add any nested elements
 
   my($key, $val);
@@ -2799,7 +2809,7 @@ XPath support.
 
 =head1 STATUS
 
-This version (2.07) is the current stable version.
+This version (2.08) is the current stable version.
 
 =head1 SEE ALSO
 
